Crate clonedir_lib

Crate clonedir_lib 

Functions

clonedir
Clones a directory with reflink https://docs.rs/reflink/*/reflink/index.html Some file systems implement COW (copy on write) functionality in order to speed up file copies. On a high level, the new file does not actually get copied, but shares the same on-disk data with the source file. As soon as one of the files is modified, the actual copying is done by the underlying OS.